cr\.cube package
================

Submodules
----------

cr\.cube\.dimension module
--------------------------

.. automodule:: cr.cube.dimension
    :members:
    :undoc-members:
    :show-inheritance:

cr\.cube\.crunch_cube module
----------------------------

.. automodule:: cr.cube.crunch_cube
    :members:
    :undoc-members:
    :show-inheritance:

Module contents
---------------

.. automodule:: cr.cube
    :members:
    :undoc-members:
    :show-inheritance:
